<?php
/*    
    Copyright (C) 2012 http://software-talk.org/ (developer@software-talk.org)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
  A collection of functions that have nothing to do with the language tagger
 * but are too small to recieve their own plugin.
 * see function_collection_settings::display_function_collection_settings()
 * for detailed description.
 */

/*
  Adds each function if it is enabled.
 */
function func_coll_add_active_functions() {
    if (get_option('option_func_coll_disable_version_tag') == 1) {
        add_filter('the_generator', 'func_coll_remove_version');
    }
    if (get_option('option_func_coll_disable_login_error') == 1) {
        add_filter('login_errors', create_function('$a', "return null;"));
    }
    if (get_option('option_func_coll_disable_selfping') == 1) {
        add_action('pre_ping', 'func_coll_disable_self_ping');
    }
    if (get_option('option_func_coll_remove_comment_clutter') == 1) {
        add_action('after_setup_theme', 'func_coll_del_comment_clutter_init');
    }
    if (get_option('option_func_coll_remove_jump') == 1) {
        add_filter('excerpt_more', 'func_coll_remove_jump');
        add_filter('the_content_more_link', 'func_coll_remove_jump');
    }
    if (get_option('option_func_coll_javascript_to_footer') == 1) {
        func_coll_javascript_to_footer();
    }

    if (get_option('option_func_coll_remove_feed_header') == 1) {
        // remove the links to the feeds in the header
        remove_action('wp_head', 'feed_links_extra', 3);
        remove_action('wp_head', 'feed_links', 2);
    }

    if (get_option('option_func_coll_remove_rel') == 1) {
        // remove rel=next and rel=prev (the seem to load the entire site...)
        remove_action('wp_head', 'start_post_rel_link', 10, 0);
        remove_action('wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);
        remove_action('wp_head', 'wlwmanifest_link');
        remove_action('wp_head', 'rsd_link');
    }

    if (get_option('option_func_coll_remove_comment_reply') == 1) {
        add_action('init', 'func_coll_remove_comment_reply');
    }

    if (get_option('option_func_coll_replace_cat_rel') == 1) {
        add_filter('the_category', 'func_coll_replace_cat_rel');
    }

    if (get_option('option_func_coll_remove_wpautop') == 1) {
        remove_filter('the_content', 'wpautop');
        remove_filter('the_excerpt', 'wpautop');
    }

    if (get_option('option_func_coll_excerpt_anchor') == 1) {
        add_filter('the_content', 'func_coll_excerpt_anchor', 10);
    }

    if (get_option('option_func_coll_remove_cat_home') == 1) {
        add_filter('pre_get_posts', 'func_coll_exclude_home_category');
    }

    if (get_option('option_func_coll_remove_cat_feed') == 1) {
        add_filter('pre_get_posts', 'func_coll_exclude_feed_category');
    }

    if (get_option('option_func_coll_add_shortcodes') == 1) {
        add_shortcode('mycloud', 'func_coll_cat_tag_cloud');
        add_shortcode('archives', 'func_coll_get_archives');
    }

    if (get_option('option_func_coll_display_num_queries') == 1) {
        add_action( 'wp_footer', 'func_coll_num_queries', 20 );
    }

}


function func_coll_num_queries() {
    if ( current_user_can('manage_options')) {
        $stat = sprintf(  '%d queries in %.3f seconds, using %.2fMB memory',
            get_num_queries(),
            timer_stop( 0, 3 ),
            memory_get_peak_usage() / 1024 / 1024
        );
        echo $stat;
    }
}

/**
 * returns a tag cloud containing tags as well as categories.
 */
function func_coll_cat_tag_cloud() {
    return wp_tag_cloud(array('echo' => false, 'number' => 35, 'largest' => 28, 'taxonomy' => array('post_tag', 'category')));
}

/**
 * returns list of archives.
 */
function func_coll_get_archives() {
    return wp_get_archives(array(
                'echo' => 0
            ));
}

/** prefix anchor links in the excerpt with link to the post */
function func_coll_excerpt_anchor($text) {
    return str_replace('href="#', 'href="' . get_permalink($post->ID) . '#', $text);
}

/** excludes a category from the feed */
function func_coll_exclude_feed_category($query) {
    if ($query->is_feed
            // && !(strpos($_SERVER["REQUEST_URI"],get_category(get_option('option_func_coll_exclude_cat')))!==false)
            && !(strpos($_SERVER["REQUEST_URI"], "category") !== false)) { // do not exclude category from category feed
        $query->set('cat', '-' . get_option('option_func_coll_exclude_cat'));
    }
    return $query;
}

/** excludes a category from home */
function func_coll_exclude_home_category($query) {
    if ($query->is_home) {
        $query->set('cat', '-' . get_option('option_func_coll_exclude_cat'));
    }
    return $query;
}

/** replaces category tag with tag (html valid) */
function func_coll_replace_cat_rel($text) {

    $valid_tag = 'rel="tag"';
    $text = str_replace('rel="category tag"', $valid_tag, $text);
    return $text;
}

function disable_autosave() {
    wp_deregister_script('autosave');
}

/** removes comment reply js script (only needed for threaded comments). */
function func_coll_remove_comment_reply() {
    wp_deregister_script('comment-reply');
}

/** moves all javascripts to footer. */
function func_coll_javascript_to_footer() {
    remove_action('wp_head', 'wp_print_scripts');
    remove_action('wp_head', 'wp_print_head_scripts', 9);
    remove_action('wp_head', 'wp_enqueue_scripts', 1);
    add_action('wp_footer', 'wp_print_scripts', 5);
    add_action('wp_footer', 'wp_enqueue_scripts', 5);
    add_action('wp_footer', 'wp_print_head_scripts', 5);
}

/** remove jump from read more link and also change text to continue.
 * // TODO these are really two functionalities, separate them
 */
function func_coll_remove_jump($post) {
    return '<a href="' . get_permalink($post->ID) . '#content" class="read-more">' . 'Continue' . '</a><br /><br />';
}

/**
  removes worpress version meta tag
 */
function func_coll_remove_version() {
    return '';
}

/**
 * disables self ping.
 * 
 * @param type $links
 */
function func_coll_disable_self_ping(&$links) {
    $blogUrl = get_option('home');
    foreach ($links as $l => $link) {
        if (0 === strpos($link, $blogUrl)) {
            unset($links[$l]);
        }
    }
}

/**
 * pagination.
 * show by calling pagination($additional_loop->max_num_pages);
 *
 * @global int $paged
 * @global type $wp_query
 * @param type $pages
 * @param type $range
 */
function pagination($pages = '', $range = 4) {
    $showitems = ($range * 2) + 1;

    global $paged;
    if (empty($paged))
        $paged = 1;

    if ($pages == '') {
        global $wp_query;
        $pages = $wp_query->max_num_pages;
        if (!$pages) {
            $pages = 1;
        }
    }

    if (1 != $pages) {
        echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"" . plugin_dir_url('function_collection.php') . "language_tagger/extra_function_collection/pagestyle.css\">";
        //echo "<div class=\"pagination\"><span>Page ".$paged." of ".$pages." </span>";
        echo "<div class=\"pagination\">";
        if ($paged > 2 && $paged > $range + 1 && $showitems < $pages)
            echo "<a href='" . get_pagenum_link(1) . "'>&laquo; First</a>";
        if ($paged > 1 && $showitems < $pages)
            echo "<a href='" . get_pagenum_link($paged - 1) . "'>&lsaquo; Previous</a>";

        for ($i = 1; $i <= $pages; $i++) {
            if (1 != $pages && (!($i >= $paged + $range + 1 || $i <= $paged - $range - 1) || $pages <= $showitems )) {
                echo ($paged == $i) ? "<span class=\"current\">" . $i . "</span>" : "<a href='" . get_pagenum_link($i) . "' class=\"inactive\">" . $i . "</a>";
            }
        }

        if ($paged < $pages && $showitems < $pages)
            echo "<a href=\"" . get_pagenum_link($paged + 1) . "\">Next &rsaquo;</a>";
        if ($paged < $pages - 1 && $paged + $range - 1 < $pages && $showitems < $pages)
            echo "<a href='" . get_pagenum_link($pages) . "'>Last &raquo;</a>";
        echo "</div>\n";
    }
}

/**
 * removes "You may use these html tags" clutter.
 */
function func_coll_del_comment_clutter_init() {
    add_filter('comment_form_defaults', 'func_coll_comments_form_defaults');
}

function func_coll_comments_form_defaults($default) {
    unset($default['comment_notes_after']);
    return $default;
}
?>
