<?php
/*    
    Copyright (C) 2012 http://software-talk.org/ (developer@software-talk.org)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
  adds a new options page to wordpress settings listing.
 */

include 'extra_function_collection/function_collection_settings.php';

if (is_admin()) {
// add options page
    add_action('admin_menu', 'language_tagger_menu');
// add language tagger options
    add_action('admin_init', 'register_language_tagger_settings');
// add function collection options
    add_action('admin_init', 'register_function_collection_settings');
}

/*
  adds option page.
 */

function language_tagger_menu() {
    add_options_page('Language Tagger Options', 'Language Tagger',
            'manage_options', 'language_tagger_unique-identifier',
            'language_tagger_options');
}

/*
  registers the settings defined in language_tagger_options.
 */

function register_language_tagger_settings() {
    register_setting('lang_tagger_option-group', 'option_default_lang_tag');
    register_setting('lang_tagger_option-group', 'option_1_lang_cat');
    register_setting('lang_tagger_option-group', 'option_1_lang');
    register_setting('lang_tagger_option-group', 'option_2_lang_cat');
    register_setting('lang_tagger_option-group', 'option_2_lang');

    register_setting('lang_tagger_option-group', 'option_use_language_meta_tag');
    register_setting('lang_tagger_option-group', 'option_use_html_lang_tag');
}

/*
  displays options.
 */

function language_tagger_options() {
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions to access this page.'));
    }
    ?>
    <div class="wrap">
        <h2>Language Tagger</h2>
        <form method="post" action="options.php">
            <?php
            settings_fields('lang_tagger_option-group');
            do_settings_fields('lang_tagger_option-group',
                    'language_tagger_unique-identifier');

// the actual settings follow below
            ?>
            <h3>Language Tagger Options</h3>
            <!-- description -->
    Adds html lang tag as well as language meta tag to all wordpress sites which helps search engines and increases Web accessibility.
    It is important that the default language option is set!

                <!-- use_language_meta_tag-->
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">use language meta tag:</th>
                    <td>
                        <input name="option_use_language_meta_tag" type="checkbox"
                            value="1" <?php checked('1', get_option('option_use_language_meta_tag')); ?> />
                    </td>
                </tr>
            </table>

            <!-- use_html_lang_tag -->
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">use html lang tag:</th>
                    <td>
                        <input name="option_use_html_lang_tag" type="checkbox"
                            value="1" <?php checked('1', get_option('option_use_html_lang_tag')); ?> />
                    </td>
                </tr>
            </table>

            <!-- default lang-->
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">default language tag (e.g.: en-US)</th>
                    <td><input type="text" name="option_default_lang_tag"
                               value="<?php echo get_option('option_default_lang_tag'); ?>" /></td>
                </tr>
            </table>

            <!-- first language -->
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">1. language tag (e.g.: de)</th>
                    <td><input type="text" name="option_1_lang"
                               value="<?php echo get_option('option_1_lang'); ?>" /></td>
                    <th scope="row"> use for category: </th>
                    <td><?php
                        wp_dropdown_categories(array('hide_empty' => 0,
                            'name' => 'option_1_lang_cat',
                            'orderby' => 'name',
                            'selected' => get_option('option_1_lang_cat'),
                            'hierarchical' => true,
                            'show_option_all'    => 'Select Category'));
                ?></td>
                </tr>
            </table>

            <!-- second language -->
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">2. language tag (e.g.: es)</th>
                    <td><input type="text" name="option_2_lang"
                               value="<?php echo get_option('option_2_lang'); ?>" /></td>
                    <th scope="row"> use for category: </th>
                    <td><?php
                        wp_dropdown_categories(array('hide_empty' => 0,
                            'name' => 'option_2_lang_cat',
                            'orderby' => 'name',
                            'selected' => get_option('option_2_lang_cat'),
                            'hierarchical' => true,
                            'show_option_all'    => 'Select Category'));
                ?></td>
                </tr>
            </table>

        <ul>

            <li><b>default language tag</b>: this will be used on all pages, on the main page,
                and on all posts that are not in a category defined by "language category" below.</li>
            <li><b>n. language category</b>: if a post is in a category named as defined in this field,
                it will not be given the default language tag, but the one defined in n. language instead. leave empty to not use it.</li>
            <li><b>use language meta tag:</b>adds 'meta http-equiv="language" content="[language-tag]"' to the header</li>
            <li><b>use html lang tag:</b>adds 'dir="ltr" lang="[language-tag]"' to the opening html tag.</li>
        </ul>

    <?php display_function_collection_settings() ?>

            <p class="submit">
                <input type="submit" class="button-primary"
                       value="<?php _e('Save Changes') ?>" />
            </p>
        </form>
        <!-- usage and description-->
        Please note that there is no input validation. The input is NOT checked for special characters, and it is NOT checked for correctness. Please check the html lang tag as well as the language meta tag yourself to see if you entered the right data above.
    </div>

    <?php
}
?>
