<?php
/*    
    Copyright (C) 2012 http://software-talk.org/ (developer@software-talk.org)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
  Plugin Name: Language Tagger
  Plugin URI: http://software-talk.org/
  Description: This plugin will add different html lang tags as well as the language meta tags depending on the settings.
  In addition to that, some small functions can be activated (they have nothing to do with the language tagger itself. They are usefull non the less, but too small for an extra plugin).
  Version: 0.1
  Author: developer
  Author URI: http://software-talk.org/
  License: GPL
 */
include 'lang_tagger_options.php';

// add function collection
include 'extra_function_collection/function_collection.php';
func_coll_add_active_functions();


// add language tagger filters
if (get_option('option_use_language_meta_tag') == 1) {
    add_filter('wp_head', 'language_tagger_addLangMetaTag');
}

if (get_option('option_use_html_lang_tag') == 1) {
    add_filter('language_attributes', 'language_tagger_change_html_lang_tag');
}

/*
 * adds the language meta tag to a post.
 * as the lang tag preceeds the language meta tag, this function is not needed
 * if language_tagger_change_html_lang_tag is used.
 */
function language_tagger_addLangMetaTag() {
    echo "<meta http-equiv=\"language\" content=\"" . language_tagger_determin_lang_tag() . "\" />";
}

/*
  function to determin the lang tag to use (depending on categories of a post).
  The output will look like this:
  dir="ltr" lang="the_determined_lang"
  This function is meant to be used to override the language_attributes wordpress function.
 */

function language_tagger_change_html_lang_tag() {
    return "dir=\"ltr\" lang=\"" . language_tagger_determin_lang_tag() . "\"";
}

function language_tagger_determin_lang_tag() {
    $postLanguage = get_option('option_default_lang_tag');
    if (is_single()) {
        global $post;
        foreach ((get_the_category($post->ID)) as $category) {
            if (get_option('option_1_lang') != "" // not used
                    && $category->cat_ID == get_option('option_1_lang_cat')) {
                $postLanguage = get_option('option_1_lang');
            } else if (get_option('option_2_lang') != ""
                    && $category->cat_ID == get_option('option_2_lang_cat')) {
                $postLanguage = get_option('option_2_lang');
            }
        }
    }
    return $postLanguage;
}

?>
